# Changelog

## [1.2.2a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/1.2.2a1) (2025-11-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V1.2.1...1.2.2a1)

**Closed issues:**

- OCP player still displayed even when no playback [\#125](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/125)

**Merged pull requests:**

- Update requirements.txt [\#167](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/167) ([JarbasAl](https://github.com/JarbasAl))

## [V1.2.1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V1.2.1) (2025-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/1.2.1...V1.2.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
